@@ -30,6 +30,7 @@ from keystoneauth1 import session as ksa_session
 from keystoneauth1 import token_endpoint as ksa_token_endpoint
 from oslo_concurrency import processutils
 from oslo_config import cfg
+from oslo_utils import strutils
 from oslo_utils import units
 
 from glance_store import capabilities
@@ -45,6 +46,7 @@ try:
     from cinderclient import api_versions
     from cinderclient import exceptions as cinder_exception
     from cinderclient.v3 import client as cinderclient
+    import os_brick
     from os_brick.initiator import connector
     from oslo_privsep import priv_context
 except ImportError:
@@ -480,6 +482,7 @@ class Store(glance_store.driver.Store):
         else:
             self.store_conf = self.conf.glance_store
         self.volume_api = cinder_utils.API()
+        getattr(os_brick, 'setup', lambda x: None)(CONF)
 
     def _set_url_prefix(self):
         self._url_prefix = "cinder://"
@@ -745,9 +748,16 @@ class Store(glance_store.driver.Store):
         else:
             attachment = self.volume_api.attachment_create(client, volume_id,
                                                            mode=attach_mode)
+        LOG.debug('Attachment %(attachment_id)s created successfully.',
+                  {'attachment_id': attachment['id']})
         attachment = self.volume_api.attachment_update(
             client, attachment['id'], connector_prop,
             mountpoint='glance_store')
+        LOG.debug('Attachment %(attachment_id)s updated successfully with '
+                  'connection info %(conn_info)s',
+                  {'attachment_id': attachment.id,
+                   'conn_info': strutils.mask_dict_password(
+                       attachment.connection_info)})
         volume = volume.manager.get(volume_id)
         connection_info = attachment.connection_info
 
@@ -792,6 +802,8 @@ class Store(glance_store.driver.Store):
             # Complete the attachment (marking the volume "in-use") after
             # the connection with os-brick is complete
             self.volume_api.attachment_complete(client, attachment.id)
+            LOG.debug('Attachment %(attachment_id)s completed successfully.',
+                      {'attachment_id': attachment.id})
             if (connection_info['driver_volume_type'] == 'rbd' and
                not conn.do_local_attach):
                 yield device['path']
@@ -819,10 +831,7 @@ class Store(glance_store.driver.Store):
                                 client, attachment.id, volume_id, host, conn,
                                 connection_info, device)
                         else:
-                            # Bug #2004555: use force so there aren't any
-                            # leftovers
-                            conn.disconnect_volume(connection_info, device,
-                                                   force=True)
+                            conn.disconnect_volume(connection_info, device)
                 except Exception:
                     LOG.exception(_LE('Failed to disconnect volume '
                                       '%(volume_id)s.'),
@@ -965,17 +974,10 @@ class Store(glance_store.driver.Store):
             LOG.info(_LI("Since image size is zero, we will be doing "
                          "resize-before-write for each GB which "
                          "will be considerably slower than normal."))
-        try:
-            volume = self.volume_api.create(client, size_gb, name=name,
-                                            metadata=metadata,
-                                            volume_type=volume_type)
-        except cinder_exception.NotFound:
-            LOG.error(_LE("Invalid volume type %s configured. Please check "
-                          "the `cinder_volume_type` configuration parameter."
-                          % volume_type))
-            msg = (_("Failed to create image-volume due to invalid "
-                     "`cinder_volume_type` configured."))
-            raise exceptions.BackendException(msg)
+
+        volume = self.volume_api.create(client, size_gb, name=name,
+                                        metadata=metadata,
+                                        volume_type=volume_type)
 
         volume = self._wait_volume_status(volume, 'creating', 'available')
         size_gb = volume.size
@@ -1057,7 +1059,7 @@ class Store(glance_store.driver.Store):
         image_metadata = {}
         location_url = 'cinder://%s' % volume.id
         if self.backend_group:
-            image_metadata['store'] = u"%s" % self.backend_group
+            image_metadata['store'] = self.backend_group
             location_url = 'cinder://%s/%s' % (self.backend_group,
                                                volume.id)
 
