@@ -19,10 +19,10 @@ A simple filesystem-backed store
 """
 
 import errno
-import hashlib
 import logging
 import os
 import stat
+import urllib
 
 import jsonschema
 from oslo_config import cfg
@@ -30,7 +30,6 @@ from oslo_serialization import jsonutils
 from oslo_utils import encodeutils
 from oslo_utils import excutils
 from oslo_utils import units
-from six.moves import urllib
 
 import glance_store
 from glance_store import capabilities
@@ -177,7 +176,7 @@ This configuration option enable the feature of not really write null byte
 sequences on the filesystem, the holes who can appear will automatically
 be interpreted by the filesystem as null bytes, and do not really consume
 your storage.
-Enabling this feature will also speed up image upload and save network trafic
+Enabling this feature will also speed up image upload and save network traffic
 in addition to save space in the backend, as null bytes sequences are not
 sent over the network.
 
@@ -739,8 +738,8 @@ class Store(glance_store.driver.Store):
 
         if os.path.exists(filepath):
             raise exceptions.Duplicate(image=filepath)
-        os_hash_value = hashlib.new(str(hashing_algo))
-        checksum = hashlib.md5()
+        os_hash_value = utils.get_hasher(hashing_algo, False)
+        checksum = utils.get_hasher('md5', False)
         bytes_written = 0
         try:
             with open(filepath, 'wb') as f:
@@ -794,7 +793,7 @@ class Store(glance_store.driver.Store):
 
         # Add store backend information to location metadata
         if self.backend_group:
-            metadata['store'] = u"%s" % self.backend_group
+            metadata['store'] = self.backend_group
 
         return ('file://%s' % filepath,
                 bytes_written,
