@@ -18,14 +18,13 @@
    (RADOS (Reliable Autonomic Distributed Object Store) Block Device)"""
 
 import contextlib
-import hashlib
 import logging
 import math
+import urllib
 
 from oslo_config import cfg
 from oslo_utils import encodeutils
 from oslo_utils import units
-from six.moves import urllib
 
 from glance_store import capabilities
 from glance_store.common import utils
@@ -159,7 +158,7 @@ Enable or not thin provisioning in this backend.
 This configuration option enable the feature of not really write null byte
 sequences on the RBD backend, the holes who can appear will automatically
 be interpreted by Ceph as null bytes, and do not really consume your storage.
-Enabling this feature will also speed up image upload and save network trafic
+Enabling this feature will also speed up image upload and save network traffic
 in addition to save space in the backend, as null bytes sequences are not
 sent over the network.
 
@@ -435,6 +434,14 @@ class Store(driver.Store):
             'snapshot': DEFAULT_SNAPNAME,
         }, self.conf)
 
+    def _snapshot_has_external_reference(self, image, snapshot_name):
+        """Returns True if snapshot has external reference else False.
+        """
+        image.set_snap(snapshot_name)
+        has_references = bool(image.list_children())
+        image.set_snap(None)
+        return has_references
+
     def _delete_image(self, target_pool, image_name,
                       snapshot_name=None, context=None):
         """
@@ -454,6 +461,14 @@ class Store(driver.Store):
                     if snapshot_name is not None:
                         with rbd.Image(ioctx, image_name) as image:
                             try:
+                                # NOTE(abhishekk): Check whether snapshot
+                                # has any external references
+                                if self._snapshot_has_external_reference(
+                                        image, snapshot_name):
+                                    raise rbd.ImageBusy(
+                                        "Image snapshot has external "
+                                        "references.")
+
                                 self._unprotect_snapshot(image, snapshot_name)
                                 image.remove_snap(snapshot_name)
                             except rbd.ImageNotFound as exc:
@@ -531,8 +546,8 @@ class Store(driver.Store):
         :raises: `glance_store.exceptions.Duplicate` if the image already
                  exists
         """
-        checksum = hashlib.md5()
-        os_hash_value = hashlib.new(str(hashing_algo))
+        os_hash_value = utils.get_hasher(hashing_algo, False)
+        checksum = utils.get_hasher('md5', False)
         image_name = str(image_id)
         with self.get_connection(conffile=self.conf_file,
                                  rados_id=self.user) as conn:
@@ -545,7 +560,7 @@ class Store(driver.Store):
                 # Fix with encodeutils.safe_decode CAN BE REMOVED
                 # after librados's fix will be stable.
                 #
-                # More informations:
+                # More information:
                 # https://bugs.launchpad.net/glance-store/+bug/1816721
                 # https://bugs.launchpad.net/cinder/+bug/1816468
                 # https://tracker.ceph.com/issues/38381
@@ -636,7 +651,7 @@ class Store(driver.Store):
         # Add store backend information to location metadata
         metadata = {}
         if self.backend_group:
-            metadata['store'] = u"%s" % self.backend_group
+            metadata['store'] = self.backend_group
 
         return (loc.get_uri(),
                 image_size,
