@@ -15,10 +15,11 @@
 
 """Storage backend for S3 or Storage Servers that follow the S3 Protocol"""
 
-import hashlib
+import io
 import logging
 import math
 import re
+import urllib
 
 from boto3 import session as boto_session
 from botocore import client as boto_client
@@ -28,8 +29,6 @@ import eventlet
 from oslo_config import cfg
 from oslo_utils import encodeutils
 from oslo_utils import units
-import six
-from six.moves import urllib
 
 import glance_store
 from glance_store import capabilities
@@ -362,7 +361,7 @@ class Store(glance_store.driver.Store):
     EXAMPLE_URL = "s3://<ACCESS_KEY>:<SECRET_KEY>@<S3_URL>/<BUCKET>/<OBJ>"
 
     READ_CHUNKSIZE = 64 * units.Ki
-    WRITE_CHUNKSIZE = READ_CHUNKSIZE
+    WRITE_CHUNKSIZE = 5 * units.Mi
 
     @staticmethod
     def get_schemes():
@@ -631,8 +630,8 @@ class Store(glance_store.driver.Store):
                   (3) checksum, (4) multihash value, and (5) a dictionary
                   with storage system specific information
         """
-        os_hash_value = hashlib.new(str(hashing_algo))
-        checksum = hashlib.md5()
+        os_hash_value = utils.get_hasher(hashing_algo, False)
+        checksum = utils.get_hasher('md5', False)
         image_data = b''
         image_size = 0
         for chunk in utils.chunkreadable(image_file, self.WRITE_CHUNKSIZE):
@@ -676,8 +675,8 @@ class Store(glance_store.driver.Store):
                   (3) checksum, (4) multihash value, and (5) a dictionary
                   with storage system specific information
         """
-        os_hash_value = hashlib.new(str(hashing_algo))
-        checksum = hashlib.md5()
+        os_hash_value = utils.get_hasher(hashing_algo, False)
+        checksum = utils.get_hasher('md5', False)
         pool_size = self.s3_store_thread_pools
         pool = eventlet.greenpool.GreenPool(size=pool_size)
         mpu = s3_client.create_multipart_upload(Bucket=bucket, Key=key)
@@ -707,7 +706,7 @@ class Store(glance_store.driver.Store):
                     checksum.update(write_chunk)
                     if verifier:
                         verifier.update(write_chunk)
-                    fp = six.BytesIO(write_chunk)
+                    fp = io.BytesIO(write_chunk)
                     fp.seek(0)
                     part = UploadPart(mpu, fp, cstart + 1, len(write_chunk))
                     pool.spawn_n(run_upload, s3_client, bucket, key, part)
@@ -722,7 +721,7 @@ class Store(glance_store.driver.Store):
                     checksum.update(write_chunk)
                     if verifier:
                         verifier.update(write_chunk)
-                    fp = six.BytesIO(write_chunk)
+                    fp = io.BytesIO(write_chunk)
                     fp.seek(0)
                     part = UploadPart(mpu, fp, cstart + 1, len(write_chunk))
                     pool.spawn_n(run_upload, s3_client, bucket, key, part)
@@ -889,7 +888,7 @@ class Store(glance_store.driver.Store):
                 {
                     'PartNumber': pnum,
                     'ETag': etag
-                } for pnum, etag in six.iteritems(pedict)
+                } for pnum, etag in pedict.items()
             ]
         }
 
