@@ -15,9 +15,9 @@
 
 """Storage backend for VMware Datastore"""
 
-import hashlib
 import logging
 import os
+import urllib.parse
 
 from oslo_config import cfg
 from oslo_utils import excutils
@@ -32,15 +32,9 @@ try:
 except ImportError:
     api = None
 
-from six.moves import urllib
-import six.moves.urllib.parse as urlparse
-
 import requests
 from requests import adapters
 from requests.packages.urllib3.util import retry
-import six
-# NOTE(jokke): simplified transition to py3, behaves like py2 xrange
-from six.moves import range
 
 import glance_store
 from glance_store import capabilities
@@ -261,8 +255,8 @@ class _Reader(object):
     def __init__(self, data, hashing_algo, verifier=None):
         self._size = 0
         self.data = data
-        self.checksum = hashlib.md5()
-        self.os_hash_value = hashlib.new(str(hashing_algo))
+        self.os_hash_value = utils.get_hasher(hashing_algo, False)
+        self.checksum = utils.get_hasher('md5', False)
         self.verifier = verifier
 
     def read(self, size=None):
@@ -350,9 +344,9 @@ class StoreLocation(location.StoreLocation):
         Creates a https url that can be used to upload/download data from a
         vmware store.
         """
-        parsed_url = urlparse.urlparse(self.get_uri())
+        parsed_url = urllib.parse.urlparse(self.get_uri())
         new_url = parsed_url._replace(scheme='https')
-        return urlparse.urlunparse(new_url)
+        return urllib.parse.urlunparse(new_url)
 
 
 class Store(glance_store.Store):
@@ -554,7 +548,7 @@ class Store(glance_store.Store):
             store_conf = self.conf.glance_store
 
         result = getattr(store_conf, param)
-        if not result:
+        if result is None:
             reason = (_("Could not find %(param)s in configuration "
                         "options.") % {'param': param})
             raise exceptions.BadStoreConfiguration(
@@ -565,7 +559,7 @@ class Store(glance_store.Store):
         """Build ESX host session cookie header."""
         if verify_session and not self.session.is_current_session_active():
             self.reset_session()
-        vim_cookies = self.session.vim.client.options.transport.cookiejar
+        vim_cookies = self.session.vim.client.cookiejar
         if len(list(vim_cookies)) > 0:
             cookie = list(vim_cookies)[0]
             return cookie.name + '=' + cookie.value
@@ -598,7 +592,7 @@ class Store(glance_store.Store):
         image_file = _Reader(image_file, hashing_algo, verifier)
         headers = {}
         if image_size > 0:
-            headers.update({'Content-Length': six.text_type(image_size)})
+            headers.update({'Content-Length': str(image_size)})
             data = image_file
         else:
             data = utils.chunkiter(image_file, CHUNKSIZE)
@@ -657,7 +651,7 @@ class Store(glance_store.Store):
 
         metadata = {}
         if self.backend_group:
-            metadata['store'] = u"%s" % self.backend_group
+            metadata['store'] = self.backend_group
 
         return (loc.get_uri(),
                 image_file.size,
@@ -805,9 +799,9 @@ class Store(glance_store.Store):
         # Note(sabari): The redirect url will have a scheme 'http(s)', but the
         # store only accepts url with scheme 'vsphere'. Thus, replacing with
         # store's scheme.
-        parsed_url = urlparse.urlparse(url)
+        parsed_url = urllib.parse.urlparse(url)
         new_url = parsed_url._replace(scheme='vsphere')
-        vsphere_url = urlparse.urlunparse(new_url)
+        vsphere_url = urllib.parse.urlunparse(new_url)
         return glance_store.location.Location(store_name,
                                               store_class,
                                               self.conf,
