@@ -16,6 +16,7 @@
 """Tests the Multiple S3 backend store"""
 
 import hashlib
+import io
 from unittest import mock
 import uuid
 
@@ -24,8 +25,8 @@ import botocore
 from botocore import exceptions as boto_exceptions
 from botocore import stub
 from oslo_config import cfg
+from oslo_utils.secretutils import md5
 from oslo_utils import units
-import six
 
 import glance_store as store
 from glance_store._drivers import s3
@@ -43,7 +44,7 @@ S3_CONF = {
     's3_store_secret_key': 'key',
     's3_store_host': 'https://s3-region1.com',
     's3_store_bucket': 'glance',
-    's3_store_large_object_size': 5,        # over 5MB is large
+    's3_store_large_object_size': 9,        # over 9MB is large
     's3_store_large_object_chunk_size': 6,  # part size is 6MB
 }
 
@@ -90,7 +91,9 @@ class TestMultiS3Store(base.MultiStoreBaseTest,
                     s3_store_secret_key='key',
                     s3_store_host='https://s3-region1.com',
                     s3_store_bucket='glance',
-                    s3_store_large_object_size=5,
+                    s3_store_large_object_size=S3_CONF[
+                        's3_store_large_object_size'
+                    ],
                     s3_store_large_object_chunk_size=6)
 
         self.config(group='s3_region2',
@@ -98,7 +101,9 @@ class TestMultiS3Store(base.MultiStoreBaseTest,
                     s3_store_secret_key='key',
                     s3_store_host='http://s3-region2.com',
                     s3_store_bucket='glance',
-                    s3_store_large_object_size=5,
+                    s3_store_large_object_size=S3_CONF[
+                        's3_store_large_object_size'
+                    ],
                     s3_store_large_object_chunk_size=6)
         # Ensure stores + locations cleared
         location.SCHEME_TO_CLS_BACKEND_MAP = {}
@@ -132,7 +137,7 @@ class TestMultiS3Store(base.MultiStoreBaseTest,
         """Test a "normal" retrieval of an image in chunks."""
         bucket, key = 'glance', FAKE_UUID
         fixture_object = {
-            'Body': six.BytesIO(b"*" * FIVE_KB),
+            'Body': io.BytesIO(b"*" * FIVE_KB),
             'ContentLength': FIVE_KB
         }
         fake_s3_client = botocore.session.get_session().create_client('s3')
@@ -203,9 +208,11 @@ class TestMultiS3Store(base.MultiStoreBaseTest,
     def test_add_singlepart(self, mock_client):
         """Test that we can add an image via the s3 backend."""
         expected_image_id = str(uuid.uuid4())
+        # 5KiB is smaller than WRITE_CHUNKSIZE
         expected_s3_size = FIVE_KB
         expected_s3_contents = b"*" * expected_s3_size
-        expected_checksum = hashlib.md5(expected_s3_contents).hexdigest()
+        expected_checksum = md5(expected_s3_contents,
+                                usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(expected_s3_contents).hexdigest()
         expected_location = format_s3_location(
             S3_CONF['s3_store_access_key'],
@@ -213,7 +220,60 @@ class TestMultiS3Store(base.MultiStoreBaseTest,
             S3_CONF['s3_store_host'],
             S3_CONF['s3_store_bucket'],
             expected_image_id)
-        image_s3 = six.BytesIO(expected_s3_contents)
+        image_s3 = io.BytesIO(expected_s3_contents)
+
+        fake_s3_client = botocore.session.get_session().create_client('s3')
+
+        with stub.Stubber(fake_s3_client) as stubber:
+            stubber.add_response(method='head_bucket',
+                                 service_response={},
+                                 expected_params={
+                                     'Bucket': S3_CONF['s3_store_bucket']
+                                 })
+            stubber.add_client_error(method='head_object',
+                                     service_error_code='404',
+                                     service_message='',
+                                     expected_params={
+                                         'Bucket': S3_CONF['s3_store_bucket'],
+                                         'Key': expected_image_id
+                                     })
+            stubber.add_response(method='put_object',
+                                 service_response={},
+                                 expected_params={
+                                     'Bucket': S3_CONF['s3_store_bucket'],
+                                     'Key': expected_image_id,
+                                     'Body': botocore.stub.ANY
+                                 })
+
+            mock_client.return_value = fake_s3_client
+            loc, size, checksum, multihash, metadata = \
+                self.store.add(expected_image_id, image_s3, expected_s3_size,
+                               self.hash_algo)
+            self.assertEqual("s3_region1", metadata["store"])
+
+            self.assertEqual(expected_location, loc)
+            self.assertEqual(expected_s3_size, size)
+            self.assertEqual(expected_checksum, checksum)
+            self.assertEqual(expected_multihash, multihash)
+
+    @mock.patch.object(boto3.session.Session, "client")
+    def test_add_singlepart_bigger_than_write_chunk(self, mock_client):
+        """Test that we can add an image via the s3 backend."""
+        expected_image_id = str(uuid.uuid4())
+        # 8 MiB is bigger than WRITE_CHUNKSIZE(=5MiB),
+        # but smaller than s3_store_large_object_size
+        expected_s3_size = 8 * units.Mi
+        expected_s3_contents = b"*" * expected_s3_size
+        expected_checksum = md5(expected_s3_contents,
+                                usedforsecurity=False).hexdigest()
+        expected_multihash = hashlib.sha256(expected_s3_contents).hexdigest()
+        expected_location = format_s3_location(
+            S3_CONF['s3_store_access_key'],
+            S3_CONF['s3_store_secret_key'],
+            S3_CONF['s3_store_host'],
+            S3_CONF['s3_store_bucket'],
+            expected_image_id)
+        image_s3 = io.BytesIO(expected_s3_contents)
 
         fake_s3_client = botocore.session.get_session().create_client('s3')
 
@@ -258,7 +318,8 @@ class TestMultiS3Store(base.MultiStoreBaseTest,
         expected_image_id = str(uuid.uuid4())
         expected_s3_size = FIVE_KB
         expected_s3_contents = b"*" * expected_s3_size
-        expected_checksum = hashlib.md5(expected_s3_contents).hexdigest()
+        expected_checksum = md5(expected_s3_contents,
+                                usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(expected_s3_contents).hexdigest()
         expected_location = format_s3_location(
             S3_CONF['s3_store_access_key'],
@@ -266,7 +327,7 @@ class TestMultiS3Store(base.MultiStoreBaseTest,
             'http://s3-region2.com',
             S3_CONF['s3_store_bucket'],
             expected_image_id)
-        image_s3 = six.BytesIO(expected_s3_contents)
+        image_s3 = io.BytesIO(expected_s3_contents)
 
         fake_s3_client = botocore.session.get_session().create_client('s3')
 
@@ -308,7 +369,7 @@ class TestMultiS3Store(base.MultiStoreBaseTest,
         expected_image_id = str(uuid.uuid4())
         expected_s3_size = FIVE_KB
         expected_s3_contents = b"*" * expected_s3_size
-        image_s3 = six.BytesIO(expected_s3_contents)
+        image_s3 = io.BytesIO(expected_s3_contents)
 
         fake_s3_client = botocore.session.get_session().create_client('s3')
         verifier = mock.MagicMock(name='mock_verifier')
@@ -331,7 +392,8 @@ class TestMultiS3Store(base.MultiStoreBaseTest,
         expected_image_id = str(uuid.uuid4())
         expected_s3_size = 16 * units.Mi
         expected_s3_contents = b"*" * expected_s3_size
-        expected_checksum = hashlib.md5(expected_s3_contents).hexdigest()
+        expected_checksum = md5(expected_s3_contents,
+                                usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(expected_s3_contents).hexdigest()
         expected_location = format_s3_location(
             S3_CONF['s3_store_access_key'],
@@ -339,7 +401,7 @@ class TestMultiS3Store(base.MultiStoreBaseTest,
             S3_CONF['s3_store_host'],
             S3_CONF['s3_store_bucket'],
             expected_image_id)
-        image_s3 = six.BytesIO(expected_s3_contents)
+        image_s3 = io.BytesIO(expected_s3_contents)
 
         fake_s3_client = botocore.session.get_session().create_client('s3')
 
@@ -421,7 +483,7 @@ class TestMultiS3Store(base.MultiStoreBaseTest,
         """Tests that adding an image with an existing identifier raises an
         appropriate exception
         """
-        image_s3 = six.BytesIO(b"never_gonna_make_it")
+        image_s3 = io.BytesIO(b"never_gonna_make_it")
 
         fake_s3_client = botocore.session.get_session().create_client('s3')
 
