@@ -13,8 +13,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
-from six.moves import urllib
+import io
+import urllib.parse
+
+from oslo_utils import units
+import requests
 
 
 def sort_url_by_qs_keys(url):
@@ -42,7 +45,7 @@ def sort_url_by_qs_keys(url):
 class FakeHTTPResponse(object):
     def __init__(self, status=200, headers=None, data=None, *args, **kwargs):
         data = data or 'I am a teapot, short and stout\n'
-        self.data = six.StringIO(data)
+        self.data = io.StringIO(data)
         self.read = self.data.read
         self.status = status
         self.headers = headers or {'content-length': len(data)}
@@ -57,3 +60,58 @@ class FakeHTTPResponse(object):
 
     def read(self, amt):
         self.data.read(amt)
+
+    def release_conn(self):
+        pass
+
+    def close(self):
+        self.data.close()
+
+
+def fake_response(status_code=200, headers=None, content=None, **kwargs):
+    r = requests.models.Response()
+    r.status_code = status_code
+    r.headers = headers or {}
+    r.raw = FakeHTTPResponse(status_code, headers, content, kwargs)
+    return r
+
+
+class FakeData(object):
+    """Generate a bunch of data without storing it in memory.
+
+    This acts like a read-only file object which generates fake data
+    in chunks when read() is called or it is used as a generator. It
+    can generate an arbitrary amount of data without storing it in
+    memory.
+
+    :param length: The number of bytes to generate
+    :param chunk_size: The chunk size to return in iteration mode, or when
+                       read() is called unbounded
+
+    """
+    def __init__(self, length, chunk_size=64 * units.Ki):
+        self._max = length
+        self._chunk_size = chunk_size
+        self._len = 0
+
+    def read(self, length=None):
+        if length is None:
+            length = self._chunk_size
+
+        length = min(length, self._max - self._len)
+
+        self._len += length
+        if length == 0:
+            return b''
+        else:
+            return b'0' * length
+
+    def __iter__(self):
+        return self
+
+    def __next__(self):
+        r = self.read()
+        if len(r) == 0:
+            raise StopIteration()
+        else:
+            return r
